==> edjchain-1.0.3.tgz: package/chaincode/edjx/go/request.go <==

package main

import (
	"cycoreutils"
	"fmt"
	"strconv"
	"github.com/hyperledger/fabric/core/chaincode/shim"
	"github.com/hyperledger/fabric/core/chaincode/lib/cid"
	"github.com/pkg/errors"
)


var RequestLogger = shim.NewLogger("request")

////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Record Request to the ledger
////////////////////////////////////////////////////////////////////////////////////////////////////////////
func recordRequest(stub shim.ChaincodeStubInterface, args []string) cycoreutils.Response {
	var err error
	var collectionName string
	var Avalbytes []byte
	var Request = &request{}

	// Convert the arg to a recordRequest object
	RequestLogger.Info("recordRequest() : Arguments for recordRequest : ", args[0])
	err = cycoreutils.JSONtoObject([]byte(args[0]), Request)
	if err != nil {
		return cycoreutils.ConstructResponse("SASTCONV002E", (errors.Wrapf(err, "Failed to convert arg[0] to Request object")).Error(), nil)
	}

	callerId, err := cid.GetID(stub)

	if err != nil {
		return cycoreutils.ConstructResponse("SASTCONV002E", (errors.Wrapf(err, "Failed to get transaction caller ID")).Error(), nil)
	}

	Request.RequesterID = callerId

	Request.ObjectType = "Request"

	// Query and Retrieve the Full recordRequest
	keys := []string{  Request.RequestID  }
	RequestLogger.Debug("Keys for Request %s: ", keys)

	collectionName = ""

	Avalbytes, err = cycoreutils.QueryObject(stub, Request.ObjectType, keys, collectionName)

	if err != nil {
		return cycoreutils.ConstructResponse("SASTQRY003E", (errors.Wrapf(err, "Failed to query Request object")).Error(), nil)
	}

	if Avalbytes != nil {
		return cycoreutils.ConstructResponse("SASTQRY008E", fmt.Sprintf("Request already exists"), nil)
	}

	RequestBytes, _ := cycoreutils.ObjecttoJSON(Request)

	err = cycoreutils.UpdateObject(stub, Request.ObjectType, keys, RequestBytes,collectionName)

	if err != nil {
		RequestLogger.Errorf("recordRequest() : Error inserting Request object into LedgerState %s", err)
		return cycoreutils.ConstructResponse("SASTUPD009E", (errors.Wrapf(err, "Request object update failed")).Error(), nil)
	}

	return cycoreutils.ConstructResponse("SASTREC011S", fmt.Sprintf("Successfully Recorded Request object"), RequestBytes)
}

//////////////////////////////////////////////////////////////
/// Query Request Info from the ledger
//////////////////////////////////////////////////////////////
func queryRequest(stub shim.ChaincodeStubInterface, args []string) cycoreutils.Response {

	var err error
	var Avalbytes []byte
	var collectionName string
	var Request = &request{}

	// In future , it should be > 1 and ,= mo_of_keys for object
	if len(args) != 1 {
		return cycoreutils.ConstructResponse("SUSRPARM001E", fmt.Sprintf("Expecting Request ID}. Received %d arguments", len(args)), nil)
	}

	Request.ObjectType = "Request"

	err = cycoreutils.JSONtoObject([]byte(args[0]), Request)
	if err != nil {
		return cycoreutils.ConstructResponse("SASTCONV002E", (errors.Wrap(err, "Failed to convert arg[0] to Request object")).Error(), nil)
	}

	// Query and Retrieve the Full Request
	keys := []string{  Request.RequestID  }
	RequestLogger.Info("Keys for Request : ", keys)

	collectionName = ""

	Avalbytes, err = cycoreutils.QueryObject(stub, Request.ObjectType, keys, collectionName)

	if err != nil {
		cycoreutils.ConstructResponse("SASTQRY003E", (errors.Wrapf(err, "Failed to query Request object")).Error(), nil)
	}

	if Avalbytes == nil {
		return cycoreutils.ConstructResponse("SASTDNE004E", fmt.Sprintf("Request not found"), nil)
	}

	err = cycoreutils.JSONtoObject(Avalbytes, Request)
	if err != nil {
		return cycoreutils.ConstructResponse("SASTCONV002E", (errors.Wrapf(err, "Failed to convert query result to Request object")).Error(), nil)
	}

	RequestLogger.Info("queryRequest() : Returning Request results")

	return cycoreutils.ConstructResponse("SASTQRY005S", fmt.Sprintf("Successfully Queried Request object"), Avalbytes)
}

//////////////////////////////////////////////////////////////
/// Query Request List from the ledger
//////////////////////////////////////////////////////////////
func queryRequestList(stub shim.ChaincodeStubInterface, args []string) cycoreutils.Response {

	var collectionName string
	collectionName = ""

	queryString := fmt.Sprintf("{\"selector\":{\"objectType\":\"Request\"}}")
	RequestLogger.Info("Query List: queryString: ", queryString)

	queryResults, err := cycoreutils.GetQueryResultForQueryString(stub, queryString,collectionName)
	if err != nil {
		return cycoreutils.ConstructResponse("SASTQRY006E", (errors.Wrapf(err, "Failed to query Request object list")).Error(), nil)
	}

	if queryResults == nil {
		return cycoreutils.ConstructResponse("SASTDNE004E", fmt.Sprintf("No Request record found"), nil)
	}

	return cycoreutils.ConstructResponse("SASTQRY007S", fmt.Sprintf("Successfully Retrieved the list of Request objects "), queryResults)
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Update Request to the ledger by getting a copy of it, updating that copy, and overwriting the original to a newer version
////////////////////////////////////////////////////////////////////////////////////////////////////////////
func updateRequest(stub shim.ChaincodeStubInterface, args []string) cycoreutils.Response {
  var err error
	var Avalbytes []byte
	var collectionName string

	var Request = &request{}
	// Convert the arg to a updateRequest object
	RequestLogger.Info("updateRequest() : Arguments for Query: Request : ", args[0])
	err = cycoreutils.JSONtoObject([]byte(args[0]), Request)
	if err != nil {
		return cycoreutils.ConstructResponse("SASTCONV002E", (errors.Wrapf(err, "Failed to convert arg[0] to Request object")).Error(), nil)
	}
	Request.ObjectType = "Request"
	// Query and Retrieve the Full updateRequest
	keys := []string{  Request.RequestID  }
	RequestLogger.Info("Keys for Request : ", keys)

	collectionName = ""

	Avalbytes, err = cycoreutils.QueryObject(stub, Request.ObjectType, keys, collectionName)


	if err != nil {
		return cycoreutils.ConstructResponse("SASTQRY003E", (errors.Wrapf(err, "Failed to query Request object")).Error(), nil)
	}

	if Avalbytes == nil {
		return cycoreutils.ConstructResponse("SASTUPD009E", fmt.Sprintf("Request does not exist to update"), nil)
	}

	var currentProps = &request{}
	err = cycoreutils.JSONtoObject(Avalbytes, currentProps)

	callerId, err := cid.GetID(stub)

	if callerId != currentProps.RequesterID {
		return cycoreutils.ConstructResponse("SASTUPD009E", fmt.Sprintf("caller is not asset owner"), nil)
	}

	Request.RequesterID = currentProps.RequesterID
	RequestBytes, _ := cycoreutils.ObjecttoJSON(Request)

	err = cycoreutils.UpdateObject(stub, Request.ObjectType, keys, RequestBytes, collectionName)

	if err != nil {
		RequestLogger.Errorf("updateRequest() : Error updating Request object into LedgerState %s", err)
		return cycoreutils.ConstructResponse("SASTUPD009E", (errors.Wrapf(err, "Request object update failed")).Error(), nil)
	}

	if Request.RequestStatus == "COMPLETE" {
		payRequestExecutor(stub, Request.RequestID)
	}

	return cycoreutils.ConstructResponse("SASTUPD010S", fmt.Sprintf("Successfully Updated Request object"), RequestBytes)
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Compute Request and pay Executor
////////////////////////////////////////////////////////////////////////////////////////////////////////////
func payRequestExecutor(stub shim.ChaincodeStubInterface, requestId string) cycoreutils.Response {
  var err error
	var Avalbytes []byte

	// Query and Retrieve the Full updateRequest
	keys := []string{  requestId  }

	Avalbytes, err = cycoreutils.QueryObject(stub, "Request", keys, "")

	if err != nil {
		return cycoreutils.ConstructResponse("SASTQRY003E", (errors.Wrapf(err, "Failed to query Request object")).Error(), nil)
	}

	if Avalbytes == nil {
		return cycoreutils.ConstructResponse("SASTDNE004E", fmt.Sprintf("Request does not exist to update"), nil)
	}

	var Request = &request{}
	err = cycoreutils.JSONtoObject(Avalbytes, Request)

	if err != nil {
		return cycoreutils.ConstructResponse("SASTQRY003E", (errors.Wrapf(err, "Failed to convert bytes to Request object")).Error(), nil)
	}

	// this should come from a formula that converts resources used to  coin

	executionSecs, _ := strconv.Atoi(Request.ExecutionSecs)
	memoryBytes, _ := strconv.Atoi(Request.MemoryBytes)
	networkBytes, _ := strconv.Atoi(Request.NetworkBytes)

	cost := calcRequestCost(executionSecs, memoryBytes, networkBytes)

	_tokenTransfer(stub, makeWalletID(Request.RequesterID), makeWalletID(Request.ExecutorID), cost)

	return cycoreutils.ConstructResponse("SASTUPD010S", fmt.Sprintf("Successfully Paid Request Executor"), Avalbytes)
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Calculate cost of Request
////////////////////////////////////////////////////////////////////////////////////////////////////////////

func calcRequestCost(ExecutionSecs int, MemoryBytes int, NetworkBytes int) int {
	// ExecutionSecs * (MemoryBytes / 1073741824)
	// ((ComputeGB-Sec * ComputePrice) + ((NetworkBytes / 1073741824) * NetworkPrice) + ((Requests / 1000000) * RequestPrice)
	Constant  := int(1073741824)
	ComputePrice := int(1)
	ComputeGBSec := ExecutionSecs * (MemoryBytes / Constant)

	NetworkPrice := int(1)

	Requests := int(1000000)
	RequestPrice := int(1)

	return (ComputeGBSec * ComputePrice) + ((NetworkBytes / Constant) * NetworkPrice) + ((Requests / 1000000) * RequestPrice)
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Delete Request from the ledger.
////////////////////////////////////////////////////////////////////////////////////////////////////////////
func deleteRequest(stub shim.ChaincodeStubInterface, args []string) cycoreutils.Response {

	var err error
	ObjectType := "Request"
	var collectionName string
	var Request = &request{}

	collectionName = ""

	// In future , it should be > 1 and ,= mo_of_keys for object
	if len(args) != 1 {
		return cycoreutils.ConstructResponse("SUSRPARM001E", fmt.Sprintf("Expecting Request ID}. Received %d arguments", len(args)), nil)
	}
	// Convert the arg to a deleteRequest object
	RequestLogger.Info("deleteRequest() : Arguments for Query: Request : ", args[0])
	err = cycoreutils.JSONtoObject([]byte(args[0]), Request)
	if err != nil {
		return cycoreutils.ConstructResponse("SASTCONV002E", (errors.Wrapf(err, "Failed to convert arg[0] to Request object")).Error(), nil)
	}

	// Query and Retrieve the Full deleteRequest
	keys := []string{  Request.RequestID  }
	RequestLogger.Info("Keys for Request : ", keys)

	err = cycoreutils.DeleteObject(stub, ObjectType, keys,collectionName)
	if err != nil {
		return cycoreutils.ConstructResponse("SASTDEL012E", (errors.Wrapf(err, "Failed to delete Request object")).Error(), nil)
	}

	return cycoreutils.ConstructResponse("SASTDEL013I", fmt.Sprintf("Successfully Deleted Request object"), nil)
}

//////////////////////////////////////////////////////////////
/// Query Request History from the ledger
//////////////////////////////////////////////////////////////
func queryRequestHistory(stub shim.ChaincodeStubInterface, args []string) cycoreutils.Response {
    	var err error
	var Avalbytes []byte
	var Request = &request{}

	// In future , it should be > 1 and ,= mo_of_keys for object
	if len(args) != 1 {
		return cycoreutils.ConstructResponse("SUSRPARM001E", fmt.Sprintf("Expecting Request ID}. Received %d arguments", len(args)), nil)
	}

	err = cycoreutils.JSONtoObject([]byte(args[0]), Request)
	if err != nil {
		return cycoreutils.ConstructResponse("SASTCONV002E", (errors.Wrapf(err, "Failed to convert arg[0] to Request object")).Error(), nil)
	}

	// Query and Retrieve the Full Request
	keys := []string{  Request.RequestID  }
	RequestLogger.Info("Keys for Request : ", keys)

    Avalbytes, err = cycoreutils.GetObjectHistory(stub, "Request", keys)
	if err != nil {
		return cycoreutils.ConstructResponse("SASTQRY003E", (errors.Wrapf(err, "Failed to query Request object history")).Error(), nil)
	}
	if Avalbytes == nil {
		return cycoreutils.ConstructResponse("SASTDNE004E", fmt.Sprintf("Request object not found"), nil)
	}

	return cycoreutils.ConstructResponse("SASTQRY014S", fmt.Sprintf("Successfully Queried Request object History"), Avalbytes)
}

==> edjchain-1.0.12.tgz: package/chaincode/edjx/go/request.go <==

package main

import (
	"cycoreutils"
	"fmt"
	"strconv"
	"github.com/hyperledger/fabric/core/chaincode/shim"
	"github.com/hyperledger/fabric/core/chaincode/lib/cid"
	"github.com/pkg/errors"
)


var RequestLogger = shim.NewLogger("request")

////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Record Request to the ledger
////////////////////////////////////////////////////////////////////////////////////////////////////////////
func recordRequest(stub shim.ChaincodeStubInterface, args []string) cycoreutils.Response {
	var err error
	var collectionName string
	var Avalbytes []byte
	var Request = &request{}

	// Convert the arg to a recordRequest object
	RequestLogger.Info("recordRequest() : Arguments for recordRequest : ", args[0])
	err = cycoreutils.JSONtoObject([]byte(args[0]), Request)
	if err != nil {
		return cycoreutils.ConstructResponse("SASTCONV002E", (errors.Wrapf(err, "Failed to convert arg[0] to Request object")).Error(), nil)
	}

	callerId, err := cid.GetID(stub)

	if err != nil {
		return cycoreutils.ConstructResponse("SASTCONV002E", (errors.Wrapf(err, "Failed to get transaction caller ID")).Error(), nil)
	}

	Request.RequesterID = callerId

	Request.ObjectType = "Request"

	// Query and Retrieve the Full recordRequest
	keys := []string{  Request.RequestID  }
	RequestLogger.Debug("Keys for Request %s: ", keys)

	collectionName = ""

	Avalbytes, err = cycoreutils.QueryObject(stub, Request.ObjectType, keys, collectionName)

	if err != nil {
		return cycoreutils.ConstructResponse("SASTQRY003E", (errors.Wrapf(err, "Failed to query Request object")).Error(), nil)
	}

	if Avalbytes != nil {
		return cycoreutils.ConstructResponse("SASTQRY008E", fmt.Sprintf("Request already exists"), nil)
	}

	RequestBytes, _ := cycoreutils.ObjecttoJSON(Request)

	err = cycoreutils.UpdateObject(stub, Request.ObjectType, keys, RequestBytes,collectionName)

	if err != nil {
		RequestLogger.Errorf("recordRequest() : Error inserting Request object into LedgerState %s", err)
		return cycoreutils.ConstructResponse("SASTUPD009E", (errors.Wrapf(err, "Request object update failed")).Error(), nil)
	}

	return cycoreutils.ConstructResponse("SASTREC011S", fmt.Sprintf("Successfully Recorded Request object"), RequestBytes)
}

//////////////////////////////////////////////////////////////
/// Query Request Info from the ledger
//////////////////////////////////////////////////////////////
func queryRequest(stub shim.ChaincodeStubInterface, args []string) cycoreutils.Response {

	var err error
	var Avalbytes []byte
	var collectionName string
	var Request = &request{}

	// In future , it should be > 1 and ,= mo_of_keys for object
	if len(args) != 1 {
		return cycoreutils.ConstructResponse("SUSRPARM001E", fmt.Sprintf("Expecting Request ID}. Received %d arguments", len(args)), nil)
	}

	Request.ObjectType = "Request"

	err = cycoreutils.JSONtoObject([]byte(args[0]), Request)
	if err != nil {
		return cycoreutils.ConstructResponse("SASTCONV002E", (errors.Wrap(err, "Failed to convert arg[0] to Request object")).Error(), nil)
	}

	// Query and Retrieve the Full Request
	keys := []string{  Request.RequestID  }
	RequestLogger.Info("Keys for Request : ", keys)

	collectionName = ""

	Avalbytes, err = cycoreutils.QueryObject(stub, Request.ObjectType, keys, collectionName)

	if err != nil {
		cycoreutils.ConstructResponse("SASTQRY003E", (errors.Wrapf(err, "Failed to query Request object")).Error(), nil)
	}

	if Avalbytes == nil {
		return cycoreutils.ConstructResponse("SASTDNE004E", fmt.Sprintf("Request not found"), nil)
	}

	err = cycoreutils.JSONtoObject(Avalbytes, Request)
	if err != nil {
		return cycoreutils.ConstructResponse("SASTCONV002E", (errors.Wrapf(err, "Failed to convert query result to Request object")).Error(), nil)
	}

	RequestLogger.Info("queryRequest() : Returning Request results")

	return cycoreutils.ConstructResponse("SASTQRY005S", fmt.Sprintf("Successfully Queried Request object"), Avalbytes)
}

//////////////////////////////////////////////////////////////
/// Query Request List from the ledger
//////////////////////////////////////////////////////////////
func queryRequestList(stub shim.ChaincodeStubInterface, args []string) cycoreutils.Response {

	var collectionName string
	collectionName = ""

	queryString := fmt.Sprintf("{\"selector\":{\"objectType\":\"Request\"}}")
	RequestLogger.Info("Query List: queryString: ", queryString)

	queryResults, err := cycoreutils.GetQueryResultForQueryString(stub, queryString,collectionName)
	if err != nil {
		return cycoreutils.ConstructResponse("SASTQRY006E", (errors.Wrapf(err, "Failed to query Request object list")).Error(), nil)
	}

	if queryResults == nil {
		return cycoreutils.ConstructResponse("SASTDNE004E", fmt.Sprintf("No Request record found"), nil)
	}

	return cycoreutils.ConstructResponse("SASTQRY007S", fmt.Sprintf("Successfully Retrieved the list of Request objects "), queryResults)
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Update Request to the ledger by getting a copy of it, updating that copy, and overwriting the original to a newer version
////////////////////////////////////////////////////////////////////////////////////////////////////////////
func updateRequest(stub shim.ChaincodeStubInterface, args []string) cycoreutils.Response {
  var err error
	var Avalbytes []byte
	var collectionName string

	var Request = &request{}
	// Convert the arg to a updateRequest object
	RequestLogger.Info("updateRequest() : Arguments for Query: Request : ", args[0])
	err = cycoreutils.JSONtoObject([]byte(args[0]), Request)
	if err != nil {
		return cycoreutils.ConstructResponse("SASTCONV002E", (errors.Wrapf(err, "Failed to convert arg[0] to Request object")).Error(), nil)
	}
	Request.ObjectType = "Request"
	// Query and Retrieve the Full updateRequest
	keys := []string{  Request.RequestID  }
	RequestLogger.Info("Keys for Request : ", keys)

	collectionName = ""

	Avalbytes, err = cycoreutils.QueryObject(stub, Request.ObjectType, keys, collectionName)


	if err != nil {
		return cycoreutils.ConstructResponse("SASTQRY003E", (errors.Wrapf(err, "Failed to query Request object")).Error(), nil)
	}

	if Avalbytes == nil {
		return cycoreutils.ConstructResponse("SASTUPD009E", fmt.Sprintf("Request does not exist to update"), nil)
	}

	var currentProps = &request{}
	err = cycoreutils.JSONtoObject(Avalbytes, currentProps)

	callerId, err := cid.GetID(stub)

	if callerId != currentProps.RequesterID {
		return cycoreutils.ConstructResponse("SASTUPD009E", fmt.Sprintf("caller is not asset owner"), nil)
	}

	Request.RequesterID = currentProps.RequesterID
	RequestBytes, _ := cycoreutils.ObjecttoJSON(Request)

	err = cycoreutils.UpdateObject(stub, Request.ObjectType, keys, RequestBytes, collectionName)

	if err != nil {
		RequestLogger.Errorf("updateRequest() : Error updating Request object into LedgerState %s", err)
		return cycoreutils.ConstructResponse("SASTUPD009E", (errors.Wrapf(err, "Request object update failed")).Error(), nil)
	}

	if Request.RequestStatus == "COMPLETE" {
		payRequestExecutor(stub, Request.RequestID)
	}

	return cycoreutils.ConstructResponse("SASTUPD010S", fmt.Sprintf("Successfully Updated Request object"), RequestBytes)
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Compute Request and pay Executor
////////////////////////////////////////////////////////////////////////////////////////////////////////////
func payRequestExecutor(stub shim.ChaincodeStubInterface, requestId string) cycoreutils.Response {
  var err error
	var Avalbytes []byte

	// Query and Retrieve the Full updateRequest
	keys := []string{  requestId  }

	Avalbytes, err = cycoreutils.QueryObject(stub, "Request", keys, "")

	if err != nil {
		return cycoreutils.ConstructResponse("SASTQRY003E", (errors.Wrapf(err, "Failed to query Request object")).Error(), nil)
	}

	if Avalbytes == nil {
		return cycoreutils.ConstructResponse("SASTDNE004E", fmt.Sprintf("Request does not exist to update"), nil)
	}

	var Request = &request{}
	err = cycoreutils.JSONtoObject(Avalbytes, Request)

	if err != nil {
		return cycoreutils.ConstructResponse("SASTQRY003E", (errors.Wrapf(err, "Failed to convert bytes to Request object")).Error(), nil)
	}

	// this should come from a formula that converts resources used to  coin

	executionSecs, _ := strconv.Atoi(Request.ExecutionSecs)
	memoryBytes, _ := strconv.Atoi(Request.MemoryBytes)
	networkBytes, _ := strconv.Atoi(Request.NetworkBytes)

	cost := calcRequestCost(executionSecs, memoryBytes, networkBytes)

	_tokenTransfer(stub, Request.RequesterID, Request.ExecutorID, cost)

	return cycoreutils.ConstructResponse("SASTUPD010S", fmt.Sprintf("Successfully Paid Request Executor"), Avalbytes)
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Calculate cost of Request
////////////////////////////////////////////////////////////////////////////////////////////////////////////

func calcRequestCost(ExecutionSecs int, MemoryBytes int, NetworkBytes int) int {
	// ExecutionSecs * (MemoryBytes / 1073741824)
	// ((ComputeGB-Sec * ComputePrice) + ((NetworkBytes / 1073741824) * NetworkPrice) + ((Requests / 1000000) * RequestPrice)
	Constant  := int(1073741824)
	ComputePrice := int(1)
	ComputeGBSec := ExecutionSecs * (MemoryBytes / Constant)

	NetworkPrice := int(1)

	Requests := int(1000000)
	RequestPrice := int(1)

	return (ComputeGBSec * ComputePrice) + ((NetworkBytes / Constant) * NetworkPrice) + ((Requests / 1000000) * RequestPrice)
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Delete Request from the ledger.
////////////////////////////////////////////////////////////////////////////////////////////////////////////
func deleteRequest(stub shim.ChaincodeStubInterface, args []string) cycoreutils.Response {

	var err error
	ObjectType := "Request"
	var collectionName string
	var Request = &request{}

	collectionName = ""

	// In future , it should be > 1 and ,= mo_of_keys for object
	if len(args) != 1 {
		return cycoreutils.ConstructResponse("SUSRPARM001E", fmt.Sprintf("Expecting Request ID}. Received %d arguments", len(args)), nil)
	}
	// Convert the arg to a deleteRequest object
	RequestLogger.Info("deleteRequest() : Arguments for Query: Request : ", args[0])
	err = cycoreutils.JSONtoObject([]byte(args[0]), Request)
	if err != nil {
		return cycoreutils.ConstructResponse("SASTCONV002E", (errors.Wrapf(err, "Failed to convert arg[0] to Request object")).Error(), nil)
	}

	// Query and Retrieve the Full deleteRequest
	keys := []string{  Request.RequestID  }
	RequestLogger.Info("Keys for Request : ", keys)

	err = cycoreutils.DeleteObject(stub, ObjectType, keys,collectionName)
	if err != nil {
		return cycoreutils.ConstructResponse("SASTDEL012E", (errors.Wrapf(err, "Failed to delete Request object")).Error(), nil)
	}

	return cycoreutils.ConstructResponse("SASTDEL013I", fmt.Sprintf("Successfully Deleted Request object"), nil)
}

//////////////////////////////////////////////////////////////
/// Query Request History from the ledger
//////////////////////////////////////////////////////////////
func queryRequestHistory(stub shim.ChaincodeStubInterface, args []string) cycoreutils.Response {
    	var err error
	var Avalbytes []byte
	var Request = &request{}

	// In future , it should be > 1 and ,= mo_of_keys for object
	if len(args) != 1 {
		return cycoreutils.ConstructResponse("SUSRPARM001E", fmt.Sprintf("Expecting Request ID}. Received %d arguments", len(args)), nil)
	}

	err = cycoreutils.JSONtoObject([]byte(args[0]), Request)
	if err != nil {
		return cycoreutils.ConstructResponse("SASTCONV002E", (errors.Wrapf(err, "Failed to convert arg[0] to Request object")).Error(), nil)
	}

	// Query and Retrieve the Full Request
	keys := []string{  Request.RequestID  }
	RequestLogger.Info("Keys for Request : ", keys)

    Avalbytes, err = cycoreutils.GetObjectHistory(stub, "Request", keys)
	if err != nil {
		return cycoreutils.ConstructResponse("SASTQRY003E", (errors.Wrapf(err, "Failed to query Request object history")).Error(), nil)
	}
	if Avalbytes == nil {
		return cycoreutils.ConstructResponse("SASTDNE004E", fmt.Sprintf("Request object not found"), nil)
	}

	return cycoreutils.ConstructResponse("SASTQRY014S", fmt.Sprintf("Successfully Queried Request object History"), Avalbytes)
}
